Title: [178607] trunk/Tools
Revision
178607
Author
[email protected]
Date
2015-01-16 15:32:33 -0800 (Fri, 16 Jan 2015)

Log Message

Regression(r178586): Caused webkitpy.w3c.test_converter_unittest.W3CTestConverterTest.test_convert_prefixed_properties to fail
https://bugs.webkit.org/show_bug.cgi?id=140568

Reviewed by Alexey Proskuryakov.

Fix the script parsing CSSPropertyNames.in to stop splitting lines
on '=' sign. The '=' sign is also used in StyleBuilder parameters:
e.g. "Longhands=background-position-x|background-position-y".
This would confuse the script and treat this as a CSS property:
"background-position-x|background-position-y".

We now split on white space and treat the first string on the line
to be the property name (this is the syntax in this file).

* Scripts/webkitpy/w3c/test_converter.py:
(_W3CTestConverter.__init__):
(_W3CTestConverter.read_webkit_prefixed_css_property_list):

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (178606 => 178607)


--- trunk/Tools/ChangeLog	2015-01-16 23:17:45 UTC (rev 178606)
+++ trunk/Tools/ChangeLog	2015-01-16 23:32:33 UTC (rev 178607)
@@ -1,3 +1,23 @@
+2015-01-16  Chris Dumez  <[email protected]>
+
+        Regression(r178586): Caused webkitpy.w3c.test_converter_unittest.W3CTestConverterTest.test_convert_prefixed_properties to fail
+        https://bugs.webkit.org/show_bug.cgi?id=140568
+
+        Reviewed by Alexey Proskuryakov.
+
+        Fix the script parsing CSSPropertyNames.in to stop splitting lines
+        on '=' sign. The '=' sign is also used in StyleBuilder parameters:
+        e.g. "Longhands=background-position-x|background-position-y".
+        This would confuse the script and treat this as a CSS property:
+        "background-position-x|background-position-y".
+
+        We now split on white space and treat the first string on the line
+        to be the property name (this is the syntax in this file).
+
+        * Scripts/webkitpy/w3c/test_converter.py:
+        (_W3CTestConverter.__init__):
+        (_W3CTestConverter.read_webkit_prefixed_css_property_list):
+
 2015-01-16  Daniel Bates  <[email protected]>
 
         REGRESSION (r171968): run-safari --simulator fails to launch Safari on iOS

Modified: trunk/Tools/Scripts/webkitpy/w3c/test_converter.py (178606 => 178607)


--- trunk/Tools/Scripts/webkitpy/w3c/test_converter.py	2015-01-16 23:17:45 UTC (rev 178606)
+++ trunk/Tools/Scripts/webkitpy/w3c/test_converter.py	2015-01-16 23:32:33 UTC (rev 178607)
@@ -75,7 +75,6 @@
         # These settings might vary between WebKit and Blink
         self._css_property_file = self.path_from_webkit_root('Source', 'WebCore', 'css', 'CSSPropertyNames.in')
         self._css_property_value_file = self.path_from_webkit_root('Source', 'WebCore', 'css', 'CSSValueKeywords.in')
-        self._css_property_split_string = '='
 
         self.test_harness_re = re.compile('/resources/testharness')
 
@@ -99,17 +98,17 @@
         unprefixed_properties = set()
 
         for line in contents.splitlines():
-            if re.match('^(#|//)', line):
-                # skip comments and preprocessor directives
+            if re.match('^(#|//)', line) or len(line.strip()) == 0:
+                # skip comments and preprocessor directives and empty lines.
                 continue
-            fields = line.split(self._css_property_split_string)
-            for prop in fields:
-                # Find properties starting with the -webkit- prefix.
-                match = re.match('-webkit-([\w|-]*)', prop)
-                if match:
-                    prefixed_properties.append(match.group(1))
-                else:
-                    unprefixed_properties.add(prop.strip())
+            # Property name is always first on the line.
+            property_name = line.split(' ', 1)[0]
+            # Find properties starting with the -webkit- prefix.
+            match = re.match('-webkit-([\w|-]*)', property_name)
+            if match:
+                prefixed_properties.append(match.group(1))
+            else:
+                unprefixed_properties.add(property_name.strip())
 
         # Ignore any prefixed properties for which an unprefixed version is supported
         return [prop for prop in prefixed_properties if prop not in unprefixed_properties]
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to